OpenID - velruse.providers.openid — Velruse 1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »

# OpenID - `velruse.providers.openid`

The OpenID provider does standard OpenID authentication, using both the Simple Registration Extension and many of the Attribute Exchange attributes to acquire as much user information to assist in the authentication process as possible.

OpenID Developer Links:

- OpenID Authentication 2.0
- Attribute Exchange 1.0

## Settings

`realm`
  Domain for your website, e.g. `http://yourdomain.com/`
`store`
  An instance of an OpenID store. The default (None) is to run in stateless mode. It is recommended to use a conforming OpenID store if possible as stateless mode can be more chatty.

Note

The OpenID store is a different store to the Velruse store. Please see the `python-openid` documentation for details.

## POST Parameters

The OpenID provider accepts openid_identifier which should designate the OpenID identifer being claimed to authenticate.

Complete Example:

    <form action="/velruse/openid/login" method="post">
        <input type="text" name="openid_identifier" />
        <input type="submit" value="Login with OpenID" />
    </form>

## Pyramid API

class `OpenIDAuthenticationComplete`(profile=None, credentials=None, provider_name=None, provider_type=None)

  Bases: `velruse.AuthenticationComplete`

  OpenID auth complete

`includeme`(config)

`add_openid_login`(config, realm=None, storage=None, login_path='/login/openid', callback_path='/login/openid/callback', name='openid')

  Add an OpenID login provider to the application.

  storage should be an object conforming to the openid.store.interface.OpenIDStore protocol. If left as None then the provider will run in a stateless mode.

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »